# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/project.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/project.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z1github.com/lyft/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\x1c\x66lyteidl/admin/project.proto\x12\x0e\x66lyteidl.admin\"\"\n\x06\x44omain\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\'\n\x07\x64omains\x18\x03 \x03(\x0b\x32\x16.flyteidl.admin.Domain\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"5\n\x08Projects\x12)\n\x08projects\x18\x01 \x03(\x0b\x32\x17.flyteidl.admin.Project\"\x14\n\x12ProjectListRequest\"B\n\x16ProjectRegisterRequest\x12(\n\x07project\x18\x01 \x01(\x0b\x32\x17.flyteidl.admin.Project\"\x19\n\x17ProjectRegisterResponseB3Z1github.com/lyft/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
)




_DOMAIN = _descriptor.Descriptor(
  name='Domain',
  full_name='flyteidl.admin.Domain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.Domain.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.admin.Domain.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=82,
)


_PROJECT = _descriptor.Descriptor(
  name='Project',
  full_name='flyteidl.admin.Project',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.Project.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.admin.Project.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domains', full_name='flyteidl.admin.Project.domains', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='flyteidl.admin.Project.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=181,
)


_PROJECTS = _descriptor.Descriptor(
  name='Projects',
  full_name='flyteidl.admin.Projects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='projects', full_name='flyteidl.admin.Projects.projects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=236,
)


_PROJECTLISTREQUEST = _descriptor.Descriptor(
  name='ProjectListRequest',
  full_name='flyteidl.admin.ProjectListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=258,
)


_PROJECTREGISTERREQUEST = _descriptor.Descriptor(
  name='ProjectRegisterRequest',
  full_name='flyteidl.admin.ProjectRegisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ProjectRegisterRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=326,
)


_PROJECTREGISTERRESPONSE = _descriptor.Descriptor(
  name='ProjectRegisterResponse',
  full_name='flyteidl.admin.ProjectRegisterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=353,
)

_PROJECT.fields_by_name['domains'].message_type = _DOMAIN
_PROJECTS.fields_by_name['projects'].message_type = _PROJECT
_PROJECTREGISTERREQUEST.fields_by_name['project'].message_type = _PROJECT
DESCRIPTOR.message_types_by_name['Domain'] = _DOMAIN
DESCRIPTOR.message_types_by_name['Project'] = _PROJECT
DESCRIPTOR.message_types_by_name['Projects'] = _PROJECTS
DESCRIPTOR.message_types_by_name['ProjectListRequest'] = _PROJECTLISTREQUEST
DESCRIPTOR.message_types_by_name['ProjectRegisterRequest'] = _PROJECTREGISTERREQUEST
DESCRIPTOR.message_types_by_name['ProjectRegisterResponse'] = _PROJECTREGISTERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Domain = _reflection.GeneratedProtocolMessageType('Domain', (_message.Message,), dict(
  DESCRIPTOR = _DOMAIN,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Domain)
  ))
_sym_db.RegisterMessage(Domain)

Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), dict(
  DESCRIPTOR = _PROJECT,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Project)
  ))
_sym_db.RegisterMessage(Project)

Projects = _reflection.GeneratedProtocolMessageType('Projects', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTS,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Projects)
  ))
_sym_db.RegisterMessage(Projects)

ProjectListRequest = _reflection.GeneratedProtocolMessageType('ProjectListRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTLISTREQUEST,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectListRequest)
  ))
_sym_db.RegisterMessage(ProjectListRequest)

ProjectRegisterRequest = _reflection.GeneratedProtocolMessageType('ProjectRegisterRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTREGISTERREQUEST,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectRegisterRequest)
  ))
_sym_db.RegisterMessage(ProjectRegisterRequest)

ProjectRegisterResponse = _reflection.GeneratedProtocolMessageType('ProjectRegisterResponse', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTREGISTERRESPONSE,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectRegisterResponse)
  ))
_sym_db.RegisterMessage(ProjectRegisterResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
