# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/execution.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.admin import common_pb2 as flyteidl_dot_admin_dot_common__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import execution_pb2 as flyteidl_dot_core_dot_execution__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/execution.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z1github.com/lyft/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\x1e\x66lyteidl/admin/execution.proto\x12\x0e\x66lyteidl.admin\x1a\x1b\x66lyteidl/admin/common.proto\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x1d\x66lyteidl/core/execution.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9f\x01\n\x16\x45xecutionCreateRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12+\n\x04spec\x18\x04 \x01(\x0b\x32\x1d.flyteidl.admin.ExecutionSpec\x12)\n\x06inputs\x18\x05 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\"`\n\x18\x45xecutionRelaunchRequest\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\x0c\n\x04name\x18\x03 \x01(\t\"Q\n\x17\x45xecutionCreateResponse\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\"U\n\x1bWorkflowExecutionGetRequest\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\"\xa3\x01\n\tExecution\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12+\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.flyteidl.admin.ExecutionSpec\x12\x31\n\x07\x63losure\x18\x03 \x01(\x0b\x32 .flyteidl.admin.ExecutionClosure\"M\n\rExecutionList\x12-\n\nexecutions\x18\x01 \x03(\x0b\x32\x19.flyteidl.admin.Execution\x12\r\n\x05token\x18\x02 \x01(\t\"T\n\x0eLiteralMapBlob\x12+\n\x06values\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x42\x06\n\x04\x64\x61ta\"1\n\rAbortMetadata\x12\r\n\x05\x63\x61use\x18\x01 \x01(\t\x12\x11\n\tprincipal\x18\x02 \x01(\t\"\xeb\x04\n\x10\x45xecutionClosure\x12\x31\n\x07outputs\x18\x01 \x01(\x0b\x32\x1e.flyteidl.admin.LiteralMapBlobH\x00\x12.\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x00\x12\x19\n\x0b\x61\x62ort_cause\x18\n \x01(\tB\x02\x18\x01H\x00\x12\x37\n\x0e\x61\x62ort_metadata\x18\x0c \x01(\x0b\x32\x1d.flyteidl.admin.AbortMetadataH\x00\x12\x36\n\x0f\x63omputed_inputs\x18\x03 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapB\x02\x18\x01\x12\x35\n\x05phase\x18\x04 \x01(\x0e\x32&.flyteidl.core.WorkflowExecution.Phase\x12.\n\nstarted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\rnotifications\x18\t \x03(\x0b\x32\x1c.flyteidl.admin.Notification\x12.\n\x0bworkflow_id\x18\x0b \x01(\x0b\x32\x19.flyteidl.core.IdentifierB\x0f\n\routput_result\"+\n\x0eSystemMetadata\x12\x19\n\x11\x65xecution_cluster\x18\x01 \x01(\t\"\xcb\x03\n\x11\x45xecutionMetadata\x12=\n\x04mode\x18\x01 \x01(\x0e\x32/.flyteidl.admin.ExecutionMetadata.ExecutionMode\x12\x11\n\tprincipal\x18\x02 \x01(\t\x12\x0f\n\x07nesting\x18\x03 \x01(\r\x12\x30\n\x0cscheduled_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\x15parent_node_execution\x18\x05 \x01(\x0b\x32&.flyteidl.core.NodeExecutionIdentifier\x12G\n\x13reference_execution\x18\x10 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\x37\n\x0fsystem_metadata\x18\x11 \x01(\x0b\x32\x1e.flyteidl.admin.SystemMetadata\"X\n\rExecutionMode\x12\n\n\x06MANUAL\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\n\n\x06SYSTEM\x10\x02\x12\x0c\n\x08RELAUNCH\x10\x03\x12\x12\n\x0e\x43HILD_WORKFLOW\x10\x04\"G\n\x10NotificationList\x12\x33\n\rnotifications\x18\x01 \x03(\x0b\x32\x1c.flyteidl.admin.Notification\"\x9c\x03\n\rExecutionSpec\x12.\n\x0blaunch_plan\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12-\n\x06inputs\x18\x02 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapB\x02\x18\x01\x12\x33\n\x08metadata\x18\x03 \x01(\x0b\x32!.flyteidl.admin.ExecutionMetadata\x12\x39\n\rnotifications\x18\x05 \x01(\x0b\x32 .flyteidl.admin.NotificationListH\x00\x12\x15\n\x0b\x64isable_all\x18\x06 \x01(\x08H\x00\x12&\n\x06labels\x18\x07 \x01(\x0b\x32\x16.flyteidl.admin.Labels\x12\x30\n\x0b\x61nnotations\x18\x08 \x01(\x0b\x32\x1b.flyteidl.admin.Annotations\x12+\n\tauth_role\x18\x10 \x01(\x0b\x32\x18.flyteidl.admin.AuthRoleB\x18\n\x16notification_overridesJ\x04\x08\x04\x10\x05\"b\n\x19\x45xecutionTerminateRequest\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\r\n\x05\x63\x61use\x18\x02 \x01(\t\"\x1c\n\x1a\x45xecutionTerminateResponse\"Y\n\x1fWorkflowExecutionGetDataRequest\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\"u\n WorkflowExecutionGetDataResponse\x12(\n\x07outputs\x18\x01 \x01(\x0b\x32\x17.flyteidl.admin.UrlBlob\x12\'\n\x06inputs\x18\x02 \x01(\x0b\x32\x17.flyteidl.admin.UrlBlobB3Z1github.com/lyft/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_admin_dot_common__pb2.DESCRIPTOR,flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,flyteidl_dot_core_dot_execution__pb2.DESCRIPTOR,flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_EXECUTIONMETADATA_EXECUTIONMODE = _descriptor.EnumDescriptor(
  name='ExecutionMode',
  full_name='flyteidl.admin.ExecutionMetadata.ExecutionMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RELAUNCH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHILD_WORKFLOW', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2088,
  serialized_end=2176,
)
_sym_db.RegisterEnumDescriptor(_EXECUTIONMETADATA_EXECUTIONMODE)


_EXECUTIONCREATEREQUEST = _descriptor.Descriptor(
  name='ExecutionCreateRequest',
  full_name='flyteidl.admin.ExecutionCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ExecutionCreateRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.ExecutionCreateRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.admin.ExecutionCreateRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='flyteidl.admin.ExecutionCreateRequest.spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='flyteidl.admin.ExecutionCreateRequest.inputs', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=397,
)


_EXECUTIONRELAUNCHREQUEST = _descriptor.Descriptor(
  name='ExecutionRelaunchRequest',
  full_name='flyteidl.admin.ExecutionRelaunchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ExecutionRelaunchRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.admin.ExecutionRelaunchRequest.name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=495,
)


_EXECUTIONCREATERESPONSE = _descriptor.Descriptor(
  name='ExecutionCreateResponse',
  full_name='flyteidl.admin.ExecutionCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ExecutionCreateResponse.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=578,
)


_WORKFLOWEXECUTIONGETREQUEST = _descriptor.Descriptor(
  name='WorkflowExecutionGetRequest',
  full_name='flyteidl.admin.WorkflowExecutionGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.WorkflowExecutionGetRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=665,
)


_EXECUTION = _descriptor.Descriptor(
  name='Execution',
  full_name='flyteidl.admin.Execution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.Execution.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='flyteidl.admin.Execution.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closure', full_name='flyteidl.admin.Execution.closure', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=668,
  serialized_end=831,
)


_EXECUTIONLIST = _descriptor.Descriptor(
  name='ExecutionList',
  full_name='flyteidl.admin.ExecutionList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executions', full_name='flyteidl.admin.ExecutionList.executions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.ExecutionList.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=910,
)


_LITERALMAPBLOB = _descriptor.Descriptor(
  name='LiteralMapBlob',
  full_name='flyteidl.admin.LiteralMapBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='flyteidl.admin.LiteralMapBlob.values', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='flyteidl.admin.LiteralMapBlob.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='flyteidl.admin.LiteralMapBlob.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=912,
  serialized_end=996,
)


_ABORTMETADATA = _descriptor.Descriptor(
  name='AbortMetadata',
  full_name='flyteidl.admin.AbortMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cause', full_name='flyteidl.admin.AbortMetadata.cause', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='principal', full_name='flyteidl.admin.AbortMetadata.principal', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=998,
  serialized_end=1047,
)


_EXECUTIONCLOSURE = _descriptor.Descriptor(
  name='ExecutionClosure',
  full_name='flyteidl.admin.ExecutionClosure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs', full_name='flyteidl.admin.ExecutionClosure.outputs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='flyteidl.admin.ExecutionClosure.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abort_cause', full_name='flyteidl.admin.ExecutionClosure.abort_cause', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abort_metadata', full_name='flyteidl.admin.ExecutionClosure.abort_metadata', index=3,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='computed_inputs', full_name='flyteidl.admin.ExecutionClosure.computed_inputs', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='flyteidl.admin.ExecutionClosure.phase', index=5,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='flyteidl.admin.ExecutionClosure.started_at', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='flyteidl.admin.ExecutionClosure.duration', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='flyteidl.admin.ExecutionClosure.created_at', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='flyteidl.admin.ExecutionClosure.updated_at', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notifications', full_name='flyteidl.admin.ExecutionClosure.notifications', index=10,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='flyteidl.admin.ExecutionClosure.workflow_id', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='output_result', full_name='flyteidl.admin.ExecutionClosure.output_result',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1050,
  serialized_end=1669,
)


_SYSTEMMETADATA = _descriptor.Descriptor(
  name='SystemMetadata',
  full_name='flyteidl.admin.SystemMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='execution_cluster', full_name='flyteidl.admin.SystemMetadata.execution_cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1714,
)


_EXECUTIONMETADATA = _descriptor.Descriptor(
  name='ExecutionMetadata',
  full_name='flyteidl.admin.ExecutionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='flyteidl.admin.ExecutionMetadata.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='principal', full_name='flyteidl.admin.ExecutionMetadata.principal', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nesting', full_name='flyteidl.admin.ExecutionMetadata.nesting', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduled_at', full_name='flyteidl.admin.ExecutionMetadata.scheduled_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_node_execution', full_name='flyteidl.admin.ExecutionMetadata.parent_node_execution', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_execution', full_name='flyteidl.admin.ExecutionMetadata.reference_execution', index=5,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system_metadata', full_name='flyteidl.admin.ExecutionMetadata.system_metadata', index=6,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXECUTIONMETADATA_EXECUTIONMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1717,
  serialized_end=2176,
)


_NOTIFICATIONLIST = _descriptor.Descriptor(
  name='NotificationList',
  full_name='flyteidl.admin.NotificationList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='notifications', full_name='flyteidl.admin.NotificationList.notifications', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2178,
  serialized_end=2249,
)


_EXECUTIONSPEC = _descriptor.Descriptor(
  name='ExecutionSpec',
  full_name='flyteidl.admin.ExecutionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='launch_plan', full_name='flyteidl.admin.ExecutionSpec.launch_plan', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='flyteidl.admin.ExecutionSpec.inputs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='flyteidl.admin.ExecutionSpec.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notifications', full_name='flyteidl.admin.ExecutionSpec.notifications', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_all', full_name='flyteidl.admin.ExecutionSpec.disable_all', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='flyteidl.admin.ExecutionSpec.labels', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='flyteidl.admin.ExecutionSpec.annotations', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_role', full_name='flyteidl.admin.ExecutionSpec.auth_role', index=7,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='notification_overrides', full_name='flyteidl.admin.ExecutionSpec.notification_overrides',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2252,
  serialized_end=2664,
)


_EXECUTIONTERMINATEREQUEST = _descriptor.Descriptor(
  name='ExecutionTerminateRequest',
  full_name='flyteidl.admin.ExecutionTerminateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ExecutionTerminateRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cause', full_name='flyteidl.admin.ExecutionTerminateRequest.cause', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2666,
  serialized_end=2764,
)


_EXECUTIONTERMINATERESPONSE = _descriptor.Descriptor(
  name='ExecutionTerminateResponse',
  full_name='flyteidl.admin.ExecutionTerminateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2766,
  serialized_end=2794,
)


_WORKFLOWEXECUTIONGETDATAREQUEST = _descriptor.Descriptor(
  name='WorkflowExecutionGetDataRequest',
  full_name='flyteidl.admin.WorkflowExecutionGetDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.WorkflowExecutionGetDataRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2796,
  serialized_end=2885,
)


_WORKFLOWEXECUTIONGETDATARESPONSE = _descriptor.Descriptor(
  name='WorkflowExecutionGetDataResponse',
  full_name='flyteidl.admin.WorkflowExecutionGetDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs', full_name='flyteidl.admin.WorkflowExecutionGetDataResponse.outputs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='flyteidl.admin.WorkflowExecutionGetDataResponse.inputs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2887,
  serialized_end=3004,
)

_EXECUTIONCREATEREQUEST.fields_by_name['spec'].message_type = _EXECUTIONSPEC
_EXECUTIONCREATEREQUEST.fields_by_name['inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_EXECUTIONRELAUNCHREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_EXECUTIONCREATERESPONSE.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_WORKFLOWEXECUTIONGETREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_EXECUTION.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_EXECUTION.fields_by_name['spec'].message_type = _EXECUTIONSPEC
_EXECUTION.fields_by_name['closure'].message_type = _EXECUTIONCLOSURE
_EXECUTIONLIST.fields_by_name['executions'].message_type = _EXECUTION
_LITERALMAPBLOB.fields_by_name['values'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_LITERALMAPBLOB.oneofs_by_name['data'].fields.append(
  _LITERALMAPBLOB.fields_by_name['values'])
_LITERALMAPBLOB.fields_by_name['values'].containing_oneof = _LITERALMAPBLOB.oneofs_by_name['data']
_LITERALMAPBLOB.oneofs_by_name['data'].fields.append(
  _LITERALMAPBLOB.fields_by_name['uri'])
_LITERALMAPBLOB.fields_by_name['uri'].containing_oneof = _LITERALMAPBLOB.oneofs_by_name['data']
_EXECUTIONCLOSURE.fields_by_name['outputs'].message_type = _LITERALMAPBLOB
_EXECUTIONCLOSURE.fields_by_name['error'].message_type = flyteidl_dot_core_dot_execution__pb2._EXECUTIONERROR
_EXECUTIONCLOSURE.fields_by_name['abort_metadata'].message_type = _ABORTMETADATA
_EXECUTIONCLOSURE.fields_by_name['computed_inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_EXECUTIONCLOSURE.fields_by_name['phase'].enum_type = flyteidl_dot_core_dot_execution__pb2._WORKFLOWEXECUTION_PHASE
_EXECUTIONCLOSURE.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXECUTIONCLOSURE.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_EXECUTIONCLOSURE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXECUTIONCLOSURE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXECUTIONCLOSURE.fields_by_name['notifications'].message_type = flyteidl_dot_admin_dot_common__pb2._NOTIFICATION
_EXECUTIONCLOSURE.fields_by_name['workflow_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_EXECUTIONCLOSURE.oneofs_by_name['output_result'].fields.append(
  _EXECUTIONCLOSURE.fields_by_name['outputs'])
_EXECUTIONCLOSURE.fields_by_name['outputs'].containing_oneof = _EXECUTIONCLOSURE.oneofs_by_name['output_result']
_EXECUTIONCLOSURE.oneofs_by_name['output_result'].fields.append(
  _EXECUTIONCLOSURE.fields_by_name['error'])
_EXECUTIONCLOSURE.fields_by_name['error'].containing_oneof = _EXECUTIONCLOSURE.oneofs_by_name['output_result']
_EXECUTIONCLOSURE.oneofs_by_name['output_result'].fields.append(
  _EXECUTIONCLOSURE.fields_by_name['abort_cause'])
_EXECUTIONCLOSURE.fields_by_name['abort_cause'].containing_oneof = _EXECUTIONCLOSURE.oneofs_by_name['output_result']
_EXECUTIONCLOSURE.oneofs_by_name['output_result'].fields.append(
  _EXECUTIONCLOSURE.fields_by_name['abort_metadata'])
_EXECUTIONCLOSURE.fields_by_name['abort_metadata'].containing_oneof = _EXECUTIONCLOSURE.oneofs_by_name['output_result']
_EXECUTIONMETADATA.fields_by_name['mode'].enum_type = _EXECUTIONMETADATA_EXECUTIONMODE
_EXECUTIONMETADATA.fields_by_name['scheduled_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXECUTIONMETADATA.fields_by_name['parent_node_execution'].message_type = flyteidl_dot_core_dot_identifier__pb2._NODEEXECUTIONIDENTIFIER
_EXECUTIONMETADATA.fields_by_name['reference_execution'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_EXECUTIONMETADATA.fields_by_name['system_metadata'].message_type = _SYSTEMMETADATA
_EXECUTIONMETADATA_EXECUTIONMODE.containing_type = _EXECUTIONMETADATA
_NOTIFICATIONLIST.fields_by_name['notifications'].message_type = flyteidl_dot_admin_dot_common__pb2._NOTIFICATION
_EXECUTIONSPEC.fields_by_name['launch_plan'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_EXECUTIONSPEC.fields_by_name['inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_EXECUTIONSPEC.fields_by_name['metadata'].message_type = _EXECUTIONMETADATA
_EXECUTIONSPEC.fields_by_name['notifications'].message_type = _NOTIFICATIONLIST
_EXECUTIONSPEC.fields_by_name['labels'].message_type = flyteidl_dot_admin_dot_common__pb2._LABELS
_EXECUTIONSPEC.fields_by_name['annotations'].message_type = flyteidl_dot_admin_dot_common__pb2._ANNOTATIONS
_EXECUTIONSPEC.fields_by_name['auth_role'].message_type = flyteidl_dot_admin_dot_common__pb2._AUTHROLE
_EXECUTIONSPEC.oneofs_by_name['notification_overrides'].fields.append(
  _EXECUTIONSPEC.fields_by_name['notifications'])
_EXECUTIONSPEC.fields_by_name['notifications'].containing_oneof = _EXECUTIONSPEC.oneofs_by_name['notification_overrides']
_EXECUTIONSPEC.oneofs_by_name['notification_overrides'].fields.append(
  _EXECUTIONSPEC.fields_by_name['disable_all'])
_EXECUTIONSPEC.fields_by_name['disable_all'].containing_oneof = _EXECUTIONSPEC.oneofs_by_name['notification_overrides']
_EXECUTIONTERMINATEREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_WORKFLOWEXECUTIONGETDATAREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_WORKFLOWEXECUTIONGETDATARESPONSE.fields_by_name['outputs'].message_type = flyteidl_dot_admin_dot_common__pb2._URLBLOB
_WORKFLOWEXECUTIONGETDATARESPONSE.fields_by_name['inputs'].message_type = flyteidl_dot_admin_dot_common__pb2._URLBLOB
DESCRIPTOR.message_types_by_name['ExecutionCreateRequest'] = _EXECUTIONCREATEREQUEST
DESCRIPTOR.message_types_by_name['ExecutionRelaunchRequest'] = _EXECUTIONRELAUNCHREQUEST
DESCRIPTOR.message_types_by_name['ExecutionCreateResponse'] = _EXECUTIONCREATERESPONSE
DESCRIPTOR.message_types_by_name['WorkflowExecutionGetRequest'] = _WORKFLOWEXECUTIONGETREQUEST
DESCRIPTOR.message_types_by_name['Execution'] = _EXECUTION
DESCRIPTOR.message_types_by_name['ExecutionList'] = _EXECUTIONLIST
DESCRIPTOR.message_types_by_name['LiteralMapBlob'] = _LITERALMAPBLOB
DESCRIPTOR.message_types_by_name['AbortMetadata'] = _ABORTMETADATA
DESCRIPTOR.message_types_by_name['ExecutionClosure'] = _EXECUTIONCLOSURE
DESCRIPTOR.message_types_by_name['SystemMetadata'] = _SYSTEMMETADATA
DESCRIPTOR.message_types_by_name['ExecutionMetadata'] = _EXECUTIONMETADATA
DESCRIPTOR.message_types_by_name['NotificationList'] = _NOTIFICATIONLIST
DESCRIPTOR.message_types_by_name['ExecutionSpec'] = _EXECUTIONSPEC
DESCRIPTOR.message_types_by_name['ExecutionTerminateRequest'] = _EXECUTIONTERMINATEREQUEST
DESCRIPTOR.message_types_by_name['ExecutionTerminateResponse'] = _EXECUTIONTERMINATERESPONSE
DESCRIPTOR.message_types_by_name['WorkflowExecutionGetDataRequest'] = _WORKFLOWEXECUTIONGETDATAREQUEST
DESCRIPTOR.message_types_by_name['WorkflowExecutionGetDataResponse'] = _WORKFLOWEXECUTIONGETDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExecutionCreateRequest = _reflection.GeneratedProtocolMessageType('ExecutionCreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONCREATEREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionCreateRequest)
  ))
_sym_db.RegisterMessage(ExecutionCreateRequest)

ExecutionRelaunchRequest = _reflection.GeneratedProtocolMessageType('ExecutionRelaunchRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONRELAUNCHREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionRelaunchRequest)
  ))
_sym_db.RegisterMessage(ExecutionRelaunchRequest)

ExecutionCreateResponse = _reflection.GeneratedProtocolMessageType('ExecutionCreateResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONCREATERESPONSE,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionCreateResponse)
  ))
_sym_db.RegisterMessage(ExecutionCreateResponse)

WorkflowExecutionGetRequest = _reflection.GeneratedProtocolMessageType('WorkflowExecutionGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWEXECUTIONGETREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowExecutionGetRequest)
  ))
_sym_db.RegisterMessage(WorkflowExecutionGetRequest)

Execution = _reflection.GeneratedProtocolMessageType('Execution', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTION,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Execution)
  ))
_sym_db.RegisterMessage(Execution)

ExecutionList = _reflection.GeneratedProtocolMessageType('ExecutionList', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONLIST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionList)
  ))
_sym_db.RegisterMessage(ExecutionList)

LiteralMapBlob = _reflection.GeneratedProtocolMessageType('LiteralMapBlob', (_message.Message,), dict(
  DESCRIPTOR = _LITERALMAPBLOB,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LiteralMapBlob)
  ))
_sym_db.RegisterMessage(LiteralMapBlob)

AbortMetadata = _reflection.GeneratedProtocolMessageType('AbortMetadata', (_message.Message,), dict(
  DESCRIPTOR = _ABORTMETADATA,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.AbortMetadata)
  ))
_sym_db.RegisterMessage(AbortMetadata)

ExecutionClosure = _reflection.GeneratedProtocolMessageType('ExecutionClosure', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONCLOSURE,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionClosure)
  ))
_sym_db.RegisterMessage(ExecutionClosure)

SystemMetadata = _reflection.GeneratedProtocolMessageType('SystemMetadata', (_message.Message,), dict(
  DESCRIPTOR = _SYSTEMMETADATA,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.SystemMetadata)
  ))
_sym_db.RegisterMessage(SystemMetadata)

ExecutionMetadata = _reflection.GeneratedProtocolMessageType('ExecutionMetadata', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONMETADATA,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionMetadata)
  ))
_sym_db.RegisterMessage(ExecutionMetadata)

NotificationList = _reflection.GeneratedProtocolMessageType('NotificationList', (_message.Message,), dict(
  DESCRIPTOR = _NOTIFICATIONLIST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NotificationList)
  ))
_sym_db.RegisterMessage(NotificationList)

ExecutionSpec = _reflection.GeneratedProtocolMessageType('ExecutionSpec', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONSPEC,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionSpec)
  ))
_sym_db.RegisterMessage(ExecutionSpec)

ExecutionTerminateRequest = _reflection.GeneratedProtocolMessageType('ExecutionTerminateRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONTERMINATEREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionTerminateRequest)
  ))
_sym_db.RegisterMessage(ExecutionTerminateRequest)

ExecutionTerminateResponse = _reflection.GeneratedProtocolMessageType('ExecutionTerminateResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONTERMINATERESPONSE,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionTerminateResponse)
  ))
_sym_db.RegisterMessage(ExecutionTerminateResponse)

WorkflowExecutionGetDataRequest = _reflection.GeneratedProtocolMessageType('WorkflowExecutionGetDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWEXECUTIONGETDATAREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowExecutionGetDataRequest)
  ))
_sym_db.RegisterMessage(WorkflowExecutionGetDataRequest)

WorkflowExecutionGetDataResponse = _reflection.GeneratedProtocolMessageType('WorkflowExecutionGetDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWEXECUTIONGETDATARESPONSE,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowExecutionGetDataResponse)
  ))
_sym_db.RegisterMessage(WorkflowExecutionGetDataResponse)


DESCRIPTOR._options = None
_EXECUTIONCLOSURE.fields_by_name['abort_cause']._options = None
_EXECUTIONCLOSURE.fields_by_name['computed_inputs']._options = None
_EXECUTIONSPEC.fields_by_name['inputs']._options = None
# @@protoc_insertion_point(module_scope)
